@@ -1289,7 +1289,7 @@ class VariableClBuilderSquashExclude(ReadonlyVariable):
         excludes = ["", "metadata"]
         important = ["distfiles", "packages", "eclass", "metadata",
                      "profiles", "layout.conf"]
-        exclude_dirs = ["profiles/templates/deprecated"]
+        exclude_dirs = ["profiles/templates/deprecated", "profiles/updates"]
 
         def generator():
             for rep_dn in self.Get('cl_builder_repository_location'):
